# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.1.0.html).

## [Unreleased]

## [0.4.3] - 2025-09-30

- fix ReadTheDocs build
- added tests


## [0.4.2] - 2025-09-29

- tests fixes


## [0.4.1] - 2025-09-29

- fix scxpand-cuda pip version


## [0.4.0] - 2025-09-29

- convert to Scverse cookiecutter template


## [0.3.6] - 2025-09-17

- `save_path` parameter in inference function - now `None` means no saving results to file
- Less redundant log messages
- Code formatting improvements


## [0.3.5] - 2025-09-16

- test release
## [0.3.4] - 2025-09-16

- Removed `device` parameter from `run_inference()` function - device is now automatically detected for optimal performance
- Reorganize the documentation

## [0.3.2] - 2025-09-15

- Renamed "main.predict" to "main.inference"

## [0.3.0] - 2025-09-14

- Initial release of scXpand
